local addonName = "System Filter"
SystemFilter = LibStub( "AceAddon-3.0" ):NewAddon( addonName,"AceConsole-3.0","AceEvent-3.0" )

-----------------------------------------------------------
-- Options and event handling
local options = {
    name = addonName,
    handler = SystemFilter,
    type = 'group',
    args = {
        hoa ={
            type = 'group',
            name = "Heart of Azeroth",
            desc = "Heart of Azeroth and Azerite control",
            order = 1,
            inline = true,
            args ={
                system = {
                    type = 'select',
                    name = "Send all Azerite information to ",
                    values = 'ListAvailableWindows',
                    get = 'GetAvailableWindows',
                    set = 'SetAvailableWindows',
                },
                color = {
                    type = 'color',
                    name = "String Color",
                    hasAlpha = false,
                    get = function()
                        local sfDB = SystemFilter.db.profile.HoA.RGB
                        return sfDB.r, sfDB.g, sfDB.b
                    end,
                    set = function( _,r,g,b,a )
                        local sfDB = SystemFilter.db.profile.HoA.RGB
                        sfDB.r = r
                        sfDB.g = g
                        sfDB.b = b
                        --refresh chat filter
                    end,
                },
            },
        },        
    },
}

function SystemFilter:ListAvailableWindows( info )
    local i, retTbl, name = 0,{},""
    for i=1, NUM_CHAT_WINDOWS do
        name = select( 1,GetChatWindowInfo( i ))
        if string.len( name ) >1 then
            retTbl[i] = name
        end
    end
    return retTbl
end

function SystemFilter:GetAvailableWindows( info )
    return self.db.profile.HoA.Tar
end

function SystemFilter:SetAvailableWindows( info,newValue )
    self.db.profile.HoA.Tar = newValue
    ChatFrame_AddMessageEventFilter( "CHAT_MSG_SYSTEM",SystemFilter["CHAT_MSG_SYSTEM"] )
end

function SystemFilter:ChatCommand( input )
    if not input or input:trim() == "" then
        LibStub('AceConfigDialog-3.0'):Open( addonName )
        --[[InterfaceOptionsFrame_OpenToCategory( self.optionsFrame )]]
    else
        LibStub( "AceConfigCmd-3.0" ):HandleCommand( "sf","systemfilter",input )
    end
end

-----------------------------------------------------------
-- DB defaults
local defaults = {
    profile = {
        HoA = {
            Tar = 3,
            RGB = {
                r = 1.0,
                g = 0.96078431,
                b = 0.41176471,
            },
        },
    },
}

-----------------------------------------------------------
-- Init
function SystemFilter:OnInitialize()
    --Disable if below version 8.0
    if select(4, GetBuildInfo()) < 80000 then self:Disable() end
    
    self.db = LibStub("AceDB-3.0"):New("SystemFilterDB", defaults, true)
    
    LibStub( "AceConfig-3.0" ):RegisterOptionsTable( addonName,options )
    self.optionsFrame = LibStub( "AceConfigDialog-3.0" ):AddToBlizOptions( addonName,addonName )
    self:RegisterChatCommand( "systemfilter","ChatCommand" )
    self:RegisterChatCommand( "sf","ChatCommand" )
    
    self:RegisterEvent( "ADDON_LOADED" )
end

function SystemFilter:OnEnable()
end

function SystemFilter:OnDisable()
end

-----------------------------------------------------------
-- Event & Chat filter Handling
function SystemFilter:ADDON_LOADED()
    self:UnregisterEvent( "ADDON_LOADED" )
    self.HoA = GetItemInfo( 158075 )
    --self:UpdateOpt()
    if self.HoA ~= nil then
        ChatFrame_AddMessageEventFilter( "CHAT_MSG_SYSTEM",SystemFilter["CHAT_MSG_SYSTEM"] )
    else
        --disable options
        --enable quest completion tracking
    end
end

function SystemFilter:CHAT_MSG_SYSTEM( event,msg,author,... )
    if msg == nil or type( msg )~= "string" then
        return false
    --Skill up, learn new skill, monies
    elseif msg:find( "Azerite" ) or msg:find( SystemFilter.HoA )then
        local sfDB = SystemFilter.db.profile.HoA.RGB
        _G[ "ChatFrame"..SystemFilter.db.profile.HoA.Tar ]:AddMessage( string.format("\124cff%.2x%.2x%.2x%s\124r", sfDB.r*255, sfDB.g*255, sfDB.b*255,"sf: "..msg ))
        return true
    end
end

-----------------------------------------------------------
-- Options table update
function SystemFilter:UpdateOpt()
    
end